[![Cover](https://github.com/pro-well-plan/opensource_apps/raw/master/resources/pwp-bgd.gif)](https://prowellplan.com)


[![Open Source Love svg2](https://badges.frapsoft.com/os/v2/open-source.svg?v=103)](https://github.com/pro-well-plan/pwploads/blob/master/LICENSE.md)
[![PyPI version](https://badge.fury.io/py/pwploads.svg)](https://badge.fury.io/py/pwploads)
[![License: LGPL v3](https://img.shields.io/badge/License-LGPL_v3-blue.svg)](https://www.gnu.org/licenses/lgpl-3.0)
[![Webapp](https://img.shields.io/badge/WebApp-On-green.svg)](https://share.streamlit.io/jcamiloangarita/opensource_apps/app.py)
[![Documentation Status](https://readthedocs.org/projects/pwploads/badge/?version=latest)](http://pwploads.readthedocs.io/?badge=latest)
[![Build Status](https://www.travis-ci.com/pro-well-plan/pwploads.svg?branch=master)](https://www.travis-ci.com/pro-well-plan/pwploads)
[![Downloads](https://pepy.tech/badge/pwploads)](https://pepy.tech/project/pwploads)

## Introduction
Pwploads is a LGPL licensed library for load cases calculations
in order to develop modern well designs easier and faster. Features are added as they
are needed; suggestions and contributions of all kinds are very welcome.

To catch up on the latest development and features, see the [changelog](CHANGELOG.md).

<a href="https://youtu.be/X7Bs9_7NdRM">
   <img alt="Qries" src="https://user-images.githubusercontent.com/52009346/102499626-b498cd00-407b-11eb-9fd9-34bc2f9ff92b.png"
   width=500" height="300">
</a>                                       
   
## Documentation

See here for the [complete pwploads package documentation](https://pwploads.readthedocs.io/en/latest/).

## Getting Started

These instructions will get you a copy of the project up and running on your local machine for development and testing purposes.

### Get pwploads

* Users: Wheels for Python from [PyPI](https://pypi.python.org/pypi/pwploads/) 
    * `pip install pwploads`
* Developers: Source code from [Github](https://github.com/pro-well-plan/pwploads)
    * `git clone https://github.com/pro-well-plan/pwploads`
    
## Contributing

Please read [CONTRIBUTING](CONTRIBUTING.md) for details on our code of conduct, and the process for submitting pull requests to us.

## History ##
Pwploads was initially written and is maintained by [Pro Well Plan
AS](http://www.prowellplan.com/) as a free, simple, easy-to-use way to analyze
load cases along the well that can be tailored to our needs, and as contribution to the
free software community.

## License

This project is licensed under the GNU Lesser General Public License v3.0 - see the [LICENSE](LICENSE.md) file for details


*for further information contact juan@prowellplan.com*

[![](https://user-images.githubusercontent.com/52009346/69100304-2eb3e800-0a5d-11ea-9a3a-8e502af2120b.png)](https://prowellplan.com)
